@@ -1,5 +1,5 @@
 package Mira::View::Archive;
-$Mira::View::Archive::VERSION = '00.07.25';
+$Mira::View::Archive::VERSION = '00.07.26';
 
 use strict;
 use warnings;
@@ -173,13 +173,13 @@ sub template {
           my $index = catfile($pensource, 'public', @show_list_address, $target);
 
           $page->{next}->{url} = @utids ? "$show_list_url/page/" . ($page_number+1) . "/index.$ext" : '' ;
-          $page->{next}->{url} =~ s{^(.*?):/+}{/}g if $page->{next}->{url};
+          $page->{next}->{url} =~ s{^(.*?):/+|/+}{/}g if $page->{next}->{url};
           $page->{next}->{title} = ($page_number+1) if $vars->{next}->{url};
           delete $page->{next} unless $page->{next}->{url};
 
           $page->{prev}->{url} = $page_number == 1 ? '' : "$show_list_url/page/" . ($page_number-1) . "/index.$ext" ;
           $page->{prev}->{url} = "$show_list_url/index.$ext" if $page_number == 2;
-          $page->{prev}->{url} =~ s{^(.*?):/+}{/} if $page->{prev}->{url};
+          $page->{prev}->{url} =~ s{^(.*?):/+|/+}{/}g if $page->{prev}->{url};
           $page->{prev}->{title} = ($page_number-1) if $vars->{prev}->{url};
           delete $page->{prev} unless $page->{prev}->{url};
 
